
a, a:hover, a:focus {
    color: black;
}

.black{
  color: black;
}

.background_gray{
  background: #F8F8F8;
  border-color: #E7E7E7;
  border: 2px solid #E7E7E7;
}

.item-panel{
  padding: 10px;
  border: 1px solid #DDD;
  border-radius: 0px;
  list-style-type: none;
}

.without-style-list{
  list-style-type: none;
}

.without-text-transform{
  text-transform: none;
}

.btn{
  text-transform: none;
}

/* Hide element */
.hide{
  display: none;
}

/*
  Margin left for buttons join and unregister forum
*/
.margin-left-unregister{
  margin-left: 1em;
}

@media screen and (min-width:1280px) {
  @-moz-document url-prefix() {
    .margin-left-moz{
      margin-left: 0.3em;
    }
  }
}

/* enable absolute positioning for within text box icon*/
.inner-addon {
    position: relative;
}

/* style icon */
.inner-addon .glyphicon {
  position: absolute;
  padding: 10px;
  pointer-events: none;
}

/* align icon */
.left-addon .glyphicon  { left:  0px;}
.right-addon .glyphicon { right: 0px;}

/* add padding  */
.left-addon input  { padding-left:  30px; }
.right-addon input { padding-right: 30px; }

/* For that not outside textarea in div*/
.in_div_textarea{
  overflow: auto;
}

/* Notifications */
.dropdown {
    display:inline-block;
    margin-left:20px;
    padding:10px;
}


.glyphicon-bell {
    font-size:1.5rem;
}

.notifications {
   min-width:420px;
}

.notifications-wrapper {
  overflow:auto;
  max-height:250px;
}

.menu-title {
 color:#ff7788;
 font-size:1.5rem;
 display:inline-block;
}

.glyphicon-circle-arrow-right {
   margin-left:5px;
}

.notification-heading, .notification-footer  {
 padding:2px 10px;
}

.dropdown-menu.divider {
  margin:5px 0;
}

.item-title {
 font-size:1.3rem;
 color:#000;
}

.notifications a.content {
 text-decoration:none;
 background:#ccc;
}

.notification-item {
 padding:10px;
 margin:5px;
 background:#ccc;
 border-radius:4px;
}

/* Topic line user */
.post-info-left {
    border-right: 1px solid #eee;
}
